/*

oer - IRC bot

See ftp://nic.funet.fi/pub/unix/irc/docs/FAQ.gz section 11 for the
definition of the word bot.

Copyright (C) 2000 EQU <equ@equnet.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/* global prototype definition */
extern char *stripnick(char *);
extern char *striphost(char *);
extern char *strsep3(char *, char *, char *);
extern char *__strsep3(char *, char *, char *);
extern char *getnextparam(char *, char *);
extern int isansi(char *);
extern int isaction(char *);
extern int isctcp(char *);
extern int emptyline(char *);
extern int iscomment(char *);
extern int isnumber(char *);
extern int wordcount(char *);
extern int parse(char *, int, char *, char *, int, int);
extern void striplf(char *);
extern void stripansi(char *);
extern void stripmirc(char *);
extern void stripchars(char *, char *);
extern void stripcntrl(char *);
extern void safequote(char *);
extern void oer_debug(int, const char *, ...);
extern void secondstostring(int, char *, int);

#ifndef HAVE_SNPRINTF
extern int snprintf(char *, size_t, const char *, ...);
#endif


